@@ -471,6 +471,11 @@ class fillVars(varsShare):
                                       matchSect.group(0),re.S)
                 if resDriver and resDriver.group(1) in list_avialable_drivers:
                     return resDriver.group(1)
+
+        videoVal = self.getValueFromCmdLine("calculate",4)
+        videoVal = {'i915':'intel'}.get(videoVal,videoVal)
+        if videoVal in list_avialable_drivers:
+            return videoVal
         defaultDriver = {
             'vesa':'vesa',
             'nvidia':'nvidia' if "nvidia" in list_avialable_drivers else "nv",
