@@ -282,6 +282,9 @@ class varsShare:
 
         ftype = typeFile(magic=0x4).getMType
         kernelfile = path.join(chroot,'boot',kernel)
+        typeKernelFile = ftype(kernelfile)
+        if typeKernelFile == None:
+            return ""
         resKernelVer = self.reFindVer.search(ftype(kernelfile))
         if resKernelVer:
             kernelVersion = "%s-%s-%s"% \
